@@ -23,7 +23,7 @@ class CustomdataApi(BaseApi):
 
     def get(self, configuration_id, **kwargs):
         # type: (string_types, dict) -> CustomData
-        """E-AC3 Codec Configuration Custom Data.  Deprecation notice: use Dolby Digital Plus instead. For more information check out our tutorial here: https://bitmovin.com/docs/encoding/tutorials/how-to-create-dolby-digital-plus-encodings 
+        """E-AC3 Codec Configuration Custom Data
 
         :param configuration_id: Id of the codec configuration
         :type configuration_id: string_types, required
